@@ -15,7 +15,9 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import copy
 import importlib
+import json
 import pprint
 import textwrap
 from types import ModuleType
@@ -62,6 +64,7 @@ class RESTObject:
     _parent_attrs: Dict[str, Any]
     _repr_attr: Optional[str] = None
     _updated_attrs: Dict[str, Any]
+    _lazy: bool
     manager: "RESTManager"
 
     def __init__(
@@ -70,6 +73,7 @@ class RESTObject:
         attrs: Dict[str, Any],
         *,
         created_from_list: bool = False,
+        lazy: bool = False,
     ) -> None:
         if not isinstance(attrs, dict):
             raise GitlabParsingError(
@@ -84,6 +88,7 @@ class RESTObject:
                 "_updated_attrs": {},
                 "_module": importlib.import_module(self.__module__),
                 "_created_from_list": created_from_list,
+                "_lazy": lazy,
             }
         )
         self.__dict__["_parent_attrs"] = self.manager.parent_attrs
@@ -101,60 +106,73 @@ class RESTObject:
         self.__dict__["_module"] = importlib.import_module(module_name)
 
     def __getattr__(self, name: str) -> Any:
-        try:
+        if name in self.__dict__["_updated_attrs"]:
             return self.__dict__["_updated_attrs"][name]
-        except KeyError:
-            try:
-                value = self.__dict__["_attrs"][name]
 
-                # If the value is a list, we copy it in the _updated_attrs dict
-                # because we are not able to detect changes made on the object
-                # (append, insert, pop, ...). Without forcing the attr
-                # creation __setattr__ is never called, the list never ends up
-                # in the _updated_attrs dict, and the update() and save()
-                # method never push the new data to the server.
-                # See https://github.com/python-gitlab/python-gitlab/issues/306
-                #
-                # note: _parent_attrs will only store simple values (int) so we
-                # don't make this check in the next except block.
-                if isinstance(value, list):
-                    self.__dict__["_updated_attrs"][name] = value[:]
-                    return self.__dict__["_updated_attrs"][name]
+        if name in self.__dict__["_attrs"]:
+            value = self.__dict__["_attrs"][name]
+            # If the value is a list, we copy it in the _updated_attrs dict
+            # because we are not able to detect changes made on the object
+            # (append, insert, pop, ...). Without forcing the attr
+            # creation __setattr__ is never called, the list never ends up
+            # in the _updated_attrs dict, and the update() and save()
+            # method never push the new data to the server.
+            # See https://github.com/python-gitlab/python-gitlab/issues/306
+            #
+            # note: _parent_attrs will only store simple values (int) so we
+            # don't make this check in the next block.
+            if isinstance(value, list):
+                self.__dict__["_updated_attrs"][name] = value[:]
+                return self.__dict__["_updated_attrs"][name]
 
-                return value
+            return value
 
-            except KeyError:
-                try:
-                    return self.__dict__["_parent_attrs"][name]
-                except KeyError as exc:
-                    message = (
-                        f"{type(self).__name__!r} object has no attribute {name!r}"
-                    )
-                    if self._created_from_list:
-                        message = (
-                            f"{message}\n\n"
-                            + textwrap.fill(
-                                f"{self.__class__!r} was created via a list() call and "
-                                f"only a subset of the data may be present. To ensure "
-                                f"all data is present get the object using a "
-                                f"get(object.id) call. For more details, see:"
-                            )
-                            + f"\n\n{_URL_ATTRIBUTE_ERROR}"
-                        )
-                    raise AttributeError(message) from exc
+        if name in self.__dict__["_parent_attrs"]:
+            return self.__dict__["_parent_attrs"][name]
+
+        message = f"{type(self).__name__!r} object has no attribute {name!r}"
+        if self._created_from_list:
+            message = (
+                f"{message}\n\n"
+                + textwrap.fill(
+                    f"{self.__class__!r} was created via a list() call and "
+                    f"only a subset of the data may be present. To ensure "
+                    f"all data is present get the object using a "
+                    f"get(object.id) call. For more details, see:"
+                )
+                + f"\n\n{_URL_ATTRIBUTE_ERROR}"
+            )
+        elif self._lazy:
+            message = f"{message}\n\n" + textwrap.fill(
+                f"If you tried to access object attributes returned from the server, "
+                f"note that {self.__class__!r} was created as a `lazy` object and was "
+                f"not initialized with any data."
+            )
+        raise AttributeError(message)
 
     def __setattr__(self, name: str, value: Any) -> None:
         self.__dict__["_updated_attrs"][name] = value
 
+    def asdict(self, *, with_parent_attrs: bool = False) -> Dict[str, Any]:
+        data = {}
+        if with_parent_attrs:
+            data.update(copy.deepcopy(self._parent_attrs))
+        data.update(copy.deepcopy(self._attrs))
+        data.update(copy.deepcopy(self._updated_attrs))
+        return data
+
+    @property
+    def attributes(self) -> Dict[str, Any]:
+        return self.asdict(with_parent_attrs=True)
+
+    def to_json(self, *, with_parent_attrs: bool = False, **kwargs: Any) -> str:
+        return json.dumps(self.asdict(with_parent_attrs=with_parent_attrs), **kwargs)
+
     def __str__(self) -> str:
-        data = self._attrs.copy()
-        data.update(self._updated_attrs)
-        return f"{type(self)} => {data}"
+        return f"{type(self)} => {self.asdict()}"
 
     def pformat(self) -> str:
-        data = self._attrs.copy()
-        data.update(self._updated_attrs)
-        return f"{type(self)} => \n{pprint.pformat(data)}"
+        return f"{type(self)} => \n{pprint.pformat(self.asdict())}"
 
     def pprint(self) -> None:
         print(self.pformat())
@@ -245,13 +263,6 @@ class RESTObject:
             obj_id = gitlab.utils.EncodedId(obj_id)
         return obj_id
 
-    @property
-    def attributes(self) -> Dict[str, Any]:
-        d = self.__dict__["_updated_attrs"].copy()
-        d.update(self.__dict__["_attrs"])
-        d.update(self.__dict__["_parent_attrs"])
-        return d
-
 
 class RESTObjectList:
     """Generator object representing a list of RESTObject's.
@@ -380,10 +391,12 @@ class RESTManager:
         if self._parent is None or not self._from_parent_attrs:
             return path
 
-        data = {
-            self_attr: getattr(self._parent, parent_attr, None)
-            for self_attr, parent_attr in self._from_parent_attrs.items()
-        }
+        data: Dict[str, Optional[gitlab.utils.EncodedId]] = {}
+        for self_attr, parent_attr in self._from_parent_attrs.items():
+            if not hasattr(self._parent, parent_attr):
+                data[self_attr] = None
+                continue
+            data[self_attr] = gitlab.utils.EncodedId(getattr(self._parent, parent_attr))
         self._parent_attrs = data
         return path.format(**data)
 
