@@ -1,10 +1,19 @@
-import warnings
-
 import pytest
 
 import gitlab
 
 
+@pytest.fixture(
+    scope="session",
+    params=[{"get_all": True}, {"all": True}],
+    ids=["get_all=True", "all=True"],
+)
+def get_all_kwargs(request):
+    """A tiny parametrized fixture to inject both `get_all=True` and
+    `all=True` to ensure they behave the same way for pagination."""
+    return request.param
+
+
 def test_auth_from_config(gl, temp_dir):
     """Test token authentication from config file"""
     test_gitlab = gitlab.Gitlab.from_config(
@@ -14,20 +23,20 @@ def test_auth_from_config(gl, temp_dir):
     assert isinstance(test_gitlab.user, gitlab.v4.objects.CurrentUser)
 
 
-def test_broadcast_messages(gl):
+def test_broadcast_messages(gl, get_all_kwargs):
     msg = gl.broadcastmessages.create({"message": "this is the message"})
     msg.color = "#444444"
     msg.save()
     msg_id = msg.id
 
-    msg = gl.broadcastmessages.list(all=True)[0]
+    msg = gl.broadcastmessages.list(**get_all_kwargs)[0]
     assert msg.color == "#444444"
 
     msg = gl.broadcastmessages.get(msg_id)
     assert msg.color == "#444444"
 
     msg.delete()
-    assert len(gl.broadcastmessages.list()) == 0
+    assert msg not in gl.broadcastmessages.list()
 
 
 def test_markdown(gl):
@@ -41,7 +50,8 @@ def test_markdown_in_project(gl, project):
 
 
 def test_lint(gl):
-    success, errors = gl.lint("Invalid")
+    with pytest.deprecated_call():
+        success, errors = gl.lint("Invalid")
     assert success is False
     assert errors
 
@@ -87,14 +97,14 @@ def test_template_dockerfile(gl):
     assert dockerfile.content is not None
 
 
-def test_template_gitignore(gl):
-    assert gl.gitignores.list(all=True)
+def test_template_gitignore(gl, get_all_kwargs):
+    assert gl.gitignores.list(**get_all_kwargs)
     gitignore = gl.gitignores.get("Node")
     assert gitignore.content is not None
 
 
-def test_template_gitlabciyml(gl):
-    assert gl.gitlabciymls.list(all=True)
+def test_template_gitlabciyml(gl, get_all_kwargs):
+    assert gl.gitlabciymls.list(**get_all_kwargs)
     gitlabciyml = gl.gitlabciymls.get("Nodejs")
     assert gitlabciyml.content is not None
 
@@ -109,19 +119,27 @@ def test_template_license(gl):
 
 def test_hooks(gl):
     hook = gl.hooks.create({"url": "http://whatever.com"})
-    assert len(gl.hooks.list()) == 1
+    assert hook in gl.hooks.list()
 
     hook.delete()
-    assert len(gl.hooks.list()) == 0
+    assert hook not in gl.hooks.list()
 
 
-def test_namespaces(gl):
-    namespace = gl.namespaces.list(all=True)
-    assert namespace
+def test_namespaces(gl, get_all_kwargs):
+    current_user = gl.user.username
 
-    namespace = gl.namespaces.list(search="root", all=True)[0]
+    namespaces = gl.namespaces.list(**get_all_kwargs)
+    assert namespaces
+
+    namespaces = gl.namespaces.list(search=current_user, **get_all_kwargs)
+    assert namespaces[0].kind == "user"
+
+    namespace = gl.namespaces.get(current_user)
     assert namespace.kind == "user"
 
+    namespace = gl.namespaces.exists(current_user)
+    assert namespace.exists
+
 
 def test_notification_settings(gl):
     settings = gl.notificationsettings.get()
@@ -151,10 +169,10 @@ def test_events(gl):
 def test_features(gl):
     feat = gl.features.set("foo", 30)
     assert feat.name == "foo"
-    assert len(gl.features.list()) == 1
+    assert feat in gl.features.list()
 
     feat.delete()
-    assert len(gl.features.list()) == 0
+    assert feat not in gl.features.list()
 
 
 def test_pagination(gl, project):
@@ -198,54 +216,46 @@ def test_rate_limits(gl):
 def test_list_default_warning(gl):
     """When there are more than 20 items and use default `list()` then warning is
     generated"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
+    with pytest.warns(UserWarning, match="python-gitlab.readthedocs.io") as record:
         gl.gitlabciymls.list()
-    assert len(caught_warnings) == 1
-    warning = caught_warnings[0]
-    assert isinstance(warning.message, UserWarning)
-    message = str(warning.message)
-    assert "python-gitlab.readthedocs.io" in message
+
+    assert len(record) == 1
+    warning = record[0]
     assert __file__ == warning.filename
 
 
-def test_list_page_nowarning(gl):
+def test_list_page_nowarning(gl, recwarn):
     """Using `page=X` will disable the warning"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
-        gl.gitlabciymls.list(page=1)
-    assert len(caught_warnings) == 0
+    gl.gitlabciymls.list(page=1)
+    assert not recwarn
 
 
-def test_list_all_false_nowarning(gl):
+def test_list_all_false_nowarning(gl, recwarn):
     """Using `all=False` will disable the warning"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
-        gl.gitlabciymls.list(all=False)
-    assert len(caught_warnings) == 0
+    gl.gitlabciymls.list(all=False)
+    assert not recwarn
 
 
-def test_list_all_true_nowarning(gl):
-    """Using `all=True` will disable the warning"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
-        items = gl.gitlabciymls.list(all=True)
-    assert len(caught_warnings) == 0
+def test_list_all_true_nowarning(gl, get_all_kwargs, recwarn):
+    """Using `get_all=True` will disable the warning"""
+    items = gl.gitlabciymls.list(**get_all_kwargs)
+    assert not recwarn
     assert len(items) > 20
 
 
-def test_list_iterator_true_nowarning(gl):
+def test_list_iterator_true_nowarning(gl, recwarn):
     """Using `iterator=True` will disable the warning"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
-        items = gl.gitlabciymls.list(iterator=True)
-    assert len(caught_warnings) == 0
+    items = gl.gitlabciymls.list(iterator=True)
+    assert not recwarn
     assert len(list(items)) > 20
 
 
 def test_list_as_list_false_warnings(gl):
     """Using `as_list=False` will disable the UserWarning but cause a
     DeprecationWarning"""
-    with warnings.catch_warnings(record=True) as caught_warnings:
+    with pytest.warns(DeprecationWarning) as record:
         items = gl.gitlabciymls.list(as_list=False)
-    assert len(caught_warnings) == 1
-    for warning in caught_warnings:
-        assert isinstance(warning.message, DeprecationWarning)
+    assert len(record) == 1
     assert len(list(items)) > 20
 
 
