@@ -22,6 +22,59 @@ def test_update_project(gitlab_cli, project):
     assert description in ret.stdout
 
 
+def test_create_ci_lint(gitlab_cli, valid_gitlab_ci_yml):
+    cmd = ["ci-lint", "create", "--content", valid_gitlab_ci_yml]
+    ret = gitlab_cli(cmd)
+
+    assert ret.success
+
+
+def test_validate_ci_lint(gitlab_cli, valid_gitlab_ci_yml):
+    cmd = ["ci-lint", "validate", "--content", valid_gitlab_ci_yml]
+    ret = gitlab_cli(cmd)
+
+    assert ret.success
+
+
+def test_validate_ci_lint_invalid_exits_non_zero(gitlab_cli, invalid_gitlab_ci_yml):
+    cmd = ["ci-lint", "validate", "--content", invalid_gitlab_ci_yml]
+    ret = gitlab_cli(cmd)
+
+    assert not ret.success
+    assert "CI YAML Lint failed (Invalid configuration format)" in ret.stderr
+
+
+def test_validate_project_ci_lint(gitlab_cli, project, valid_gitlab_ci_yml):
+    cmd = [
+        "project-ci-lint",
+        "validate",
+        "--project-id",
+        project.id,
+        "--content",
+        valid_gitlab_ci_yml,
+    ]
+    ret = gitlab_cli(cmd)
+
+    assert ret.success
+
+
+def test_validate_project_ci_lint_invalid_exits_non_zero(
+    gitlab_cli, project, invalid_gitlab_ci_yml
+):
+    cmd = [
+        "project-ci-lint",
+        "validate",
+        "--project-id",
+        project.id,
+        "--content",
+        invalid_gitlab_ci_yml,
+    ]
+    ret = gitlab_cli(cmd)
+
+    assert not ret.success
+    assert "CI YAML Lint failed (Invalid configuration format)" in ret.stderr
+
+
 def test_create_group(gitlab_cli):
     name = "test-group1"
     path = "group1"
@@ -123,31 +176,6 @@ def test_list_user_memberships(gitlab_cli, user):
     assert ret.success
 
 
-def test_project_create_file(gitlab_cli, project):
-    file_path = "README"
-    branch = "main"
-    content = "CONTENT"
-    commit_message = "Initial commit"
-
-    cmd = [
-        "project-file",
-        "create",
-        "--project-id",
-        project.id,
-        "--file-path",
-        file_path,
-        "--branch",
-        branch,
-        "--content",
-        content,
-        "--commit-message",
-        commit_message,
-    ]
-    ret = gitlab_cli(cmd)
-
-    assert ret.success
-
-
 def test_create_project_issue(gitlab_cli, project):
     title = "my issue"
     description = "my issue description"
@@ -249,34 +277,6 @@ def test_accept_request_merge(gitlab_cli, project):
     assert ret.success
 
 
-def test_revert_commit(gitlab_cli, project):
-    commit = project.commits.list()[0]
-
-    cmd = [
-        "project-commit",
-        "revert",
-        "--project-id",
-        project.id,
-        "--id",
-        commit.id,
-        "--branch",
-        "main",
-    ]
-    ret = gitlab_cli(cmd)
-
-    assert ret.success
-
-
-def test_get_commit_signature_not_found(gitlab_cli, project):
-    commit = project.commits.list()[0]
-
-    cmd = ["project-commit", "signature", "--project-id", project.id, "--id", commit.id]
-    ret = gitlab_cli(cmd)
-
-    assert not ret.success
-    assert "404 Signature Not Found" in ret.stderr
-
-
 def test_create_project_label(gitlab_cli, project):
     name = "prjlabel1"
     description = "prjlabel1 description"
