@@ -9,9 +9,7 @@ import pytest
 
 import gitlab
 import gitlab.base
-
-SLEEP_INTERVAL = 0.5
-TIMEOUT = 60  # seconds before timeout will occur
+from tests.functional import helpers
 
 
 @pytest.fixture(scope="session")
@@ -19,70 +17,47 @@ def fixture_dir(test_dir):
     return test_dir / "functional" / "fixtures"
 
 
-def reset_gitlab(gl):
-    # previously tools/reset_gitlab.py
+def reset_gitlab(gl: gitlab.Gitlab) -> None:
+    """Delete resources (such as projects, groups, users) that shouldn't
+    exist."""
+    if is_gitlab_ee(gl):
+        logging.info("GitLab EE detected")
+        # NOTE(jlvillal): By default in GitLab EE it will wait 7 days before
+        # deleting a group. Change it to 0 days.
+        settings = gl.settings.get()
+        if settings.deletion_adjourned_period != 0:
+            logging.info("Setting deletion_adjourned_period to 0")
+            settings.deletion_adjourned_period = 0
+            settings.save()
+
     for project in gl.projects.list():
-        logging.info(f"Marking for deletion project: {project.path_with_namespace!r}")
         for deploy_token in project.deploytokens.list():
             logging.info(
-                f"Marking for deletion token: {deploy_token.username!r} in "
+                f"Deleting deploy token: {deploy_token.username!r} in "
                 f"project: {project.path_with_namespace!r}"
             )
-            deploy_token.delete()
-        project.delete()
+            helpers.safe_delete(deploy_token)
+        logging.info(f"Deleting project: {project.path_with_namespace!r}")
+        helpers.safe_delete(project)
     for group in gl.groups.list():
-        logging.info(f"Marking for deletion group: {group.full_path!r}")
         for deploy_token in group.deploytokens.list():
             logging.info(
-                f"Marking for deletion token: {deploy_token.username!r} in "
+                f"Deleting deploy token: {deploy_token.username!r} in "
                 f"group: {group.path_with_namespace!r}"
             )
-            deploy_token.delete()
-        group.delete()
+            helpers.safe_delete(deploy_token)
+        logging.info(f"Deleting group: {group.full_path!r}")
+        helpers.safe_delete(group)
     for topic in gl.topics.list():
-        topic.delete()
+        logging.info(f"Deleting topic: {topic.name!r}")
+        helpers.safe_delete(topic)
     for variable in gl.variables.list():
-        logging.info(f"Marking for deletion variable: {variable.key!r}")
-        variable.delete()
+        logging.info(f"Deleting variable: {variable.key!r}")
+        helpers.safe_delete(variable)
     for user in gl.users.list():
         if user.username != "root":
-            logging.info(f"Marking for deletion user: {user.username!r}")
-            user.delete(hard_delete=True)
-
-    max_iterations = int(TIMEOUT / SLEEP_INTERVAL)
-
-    # Ensure everything has been reset
-    start_time = time.perf_counter()
-
-    def wait_for_list_size(
-        rest_manager: gitlab.base.RESTManager, description: str, max_length: int = 0
-    ) -> None:
-        """Wait for the list() length to be no greater than expected maximum or fail
-        test if timeout is exceeded"""
-        logging.info(f"Checking {description!r} has no more than {max_length} items")
-        for count in range(max_iterations):
-            items = rest_manager.list()
-            if len(items) <= max_length:
-                break
-            logging.info(
-                f"Iteration: {count} Waiting for {description!r} items to be deleted: "
-                f"{[x.name for x in items]}"
-            )
-            time.sleep(SLEEP_INTERVAL)
-
-        elapsed_time = time.perf_counter() - start_time
-        error_message = (
-            f"More than {max_length} {description!r} items still remaining and timeout "
-            f"({elapsed_time}) exceeded: {[x.name for x in items]}"
-        )
-        if len(items) > max_length:
-            logging.error(error_message)
-        assert len(items) <= max_length, error_message
-
-    wait_for_list_size(rest_manager=gl.projects, description="projects")
-    wait_for_list_size(rest_manager=gl.groups, description="groups")
-    wait_for_list_size(rest_manager=gl.variables, description="variables")
-    wait_for_list_size(rest_manager=gl.users, description="users", max_length=1)
+            logging.info(f"Deleting user: {user.username!r}")
+            helpers.safe_delete(user, hard_delete=True)
 
 
 def set_token(container, fixture_dir):
@@ -238,6 +213,23 @@ def gl(gitlab_config):
     return instance
 
 
+def is_gitlab_ee(gl: gitlab.Gitlab) -> bool:
+    """Determine if we are running with GitLab EE as opposed to GitLab CE"""
+    try:
+        license = gl.get_license()
+    except gitlab.exceptions.GitlabLicenseError:
+        license = None
+    # If we have a license then we assume we are running on GitLab EE
+    if license:
+        return True
+    return False
+
+
+@pytest.fixture(scope="session")
+def gitlab_ee(gl) -> bool:
+    return is_gitlab_ee(gl=gl)
+
+
 @pytest.fixture(scope="session")
 def gitlab_runner(gl):
     container = "gitlab-runner-test"
@@ -280,10 +272,7 @@ def group(gl):
 
     yield group
 
-    try:
-        group.delete()
-    except gitlab.exceptions.GitlabDeleteError as e:
-        print(f"Group already deleted: {e}")
+    helpers.safe_delete(group)
 
 
 @pytest.fixture(scope="module")
@@ -296,10 +285,7 @@ def project(gl):
 
     yield project
 
-    try:
-        project.delete()
-    except gitlab.exceptions.GitlabDeleteError as e:
-        print(f"Project already deleted: {e}")
+    helpers.safe_delete(project)
 
 
 @pytest.fixture(scope="function")
@@ -327,7 +313,7 @@ def merge_request(project, wait_for_sidekiq):
         assert result is True, "sidekiq process should have terminated but did not"
 
         project.refresh()  # Gets us the current default branch
-        project.branches.create(
+        mr_branch = project.branches.create(
             {"branch": source_branch, "ref": project.default_branch}
         )
         # NOTE(jlvillal): Must create a commit in the new branch before we can
@@ -359,18 +345,13 @@ def merge_request(project, wait_for_sidekiq):
             time.sleep(0.5)
         assert mr.merge_status != "checking"
 
-        to_delete.append((mr.iid, source_branch))
+        to_delete.extend([mr, mr_branch])
         return mr
 
     yield _merge_request
 
-    for mr_iid, source_branch in to_delete:
-        project.mergerequests.delete(mr_iid)
-        try:
-            project.branches.delete(source_branch)
-        except gitlab.exceptions.GitlabDeleteError:
-            # Ignore if branch was already deleted
-            pass
+    for object in to_delete:
+        helpers.safe_delete(object)
 
 
 @pytest.fixture(scope="module")
@@ -391,7 +372,7 @@ def project_file(project):
 @pytest.fixture(scope="function")
 def release(project, project_file):
     _id = uuid.uuid4().hex
-    name = f"test-release-{_id}"
+    name = f"we_have_a_slash/test-release-{_id}"
 
     project.refresh()  # Gets us the current default branch
     release = project.releases.create(
@@ -434,11 +415,8 @@ def user(gl):
 
     yield user
 
-    try:
-        # Use `hard_delete=True` or a 'Ghost User' may be created.
-        user.delete(hard_delete=True)
-    except gitlab.exceptions.GitlabDeleteError as e:
-        print(f"User already deleted: {e}")
+    # Use `hard_delete=True` or a 'Ghost User' may be created.
+    helpers.safe_delete(user, hard_delete=True)
 
 
 @pytest.fixture(scope="module")
